# SPDX-FileCopyrightText: 2023-present Massimiliano Pippi <mpippi@gmail.com>
#
# SPDX-License-Identifier: Apache-2.0
import sys

if __name__ == "__main__":
    from hayhooks.cli import hayhooks

    sys.exit(hayhooks())
